Pool

Struct Pool 

pub struct Pool<K, I> { /* private fields */ }
A keep-alive connection pool.

Implementations

Source

impl<K, I> Pool<K, I>
where K: Eq + Hash,

pub fn new(capacity: usize) -> Self

Creates a new connection pool with the given limit.

pub fn new_unbounded() -> Self

Creates a new connection pool with no limit.

pub fn set_local_limit(&self, limit: usize) -> usize

Sets a local limit for a key. Returns the index for the local limit.

pub async fn pull(&self, key: K) -> Item<K, I>

Pulls an item from the pool. This method waits, when the global limit is reached.

pub async fn pull_with_local_limit( &self, key: K, local_limit_index: Option<usize>, ) -> Option<Item<K, I>>

Attempts to pull an item from the pool (with local limit applied). This method waits, when the global limit is reached, and returns None, when a local limit is reached.

pub async fn pull_with_wait_local_limit( &self, key: K, local_limit_index: Option<usize>, ) -> Item<K, I>

Pulls an item from the pool (with local limit applied). This method waits, when either the global limit or a local limit is reached.

pub fn try_pull(&self, key: K) -> Option<Item<K, I>>

Attempts to pull an item from the pool. This method returns None, when the global limit is reached.

pub fn try_pull_with_local_limit( &self, key: K, local_limit_index: Option<usize>, ) -> Option<Item<K, I>>

Attempts to pull an item from the pool (with local limit applied). This method returns None, when either the global limit or a local limit is reached.